@@ -25,7 +25,17 @@ $(".docs-sidebar-section ol > li > a").click(function () {
     event.preventDefault();
 });
 
-$('ol > li:has(ul)').addClass('docs-has-sub');
+/* Bug #1417291
+   The rule below creates a shaded plus sign next to 
+   a numbered sublist of a bulleted list.
+   It's probably there to implement expand/collapse of
+   list items, but unfortunately it affects also those
+   lists where expand/collapse is not intended.
+
+   I am commenting it out to fix this bug. If it causes
+   problems elsewhere, they have to be fixed elsewhere. */
+
+// $('ol > li:has(ul)').addClass('docs-has-sub');
 
 // webui popover
 $(document).ready(function() {
@@ -76,7 +86,33 @@ $.getJSON('common/js/doc-characters.json', function(data) {
   $('<p>' + item.caption + '<strong>OpenStack Operator</strong></p>').appendTo('#superuser-img');
 });
 
+/* BB 150310
+   openstackdocstheme provides three types of admonitions, important, note 
+   and warning. We decorate their title paragraphs with Font Awesome icons
+   by adding the appropriate FA classes.                               */
 
+$('div.important > p.admonition-title').addClass('fa fa-info-circle');
+$('div.note > p.admonition-title').addClass('fa fa-check-circle');
+$('div.warning > p.admonition-title').addClass('fa fa-exclamation-triangle');
 
+/* BB 150310
+   We also insert a space between the icon and the admonition title 
+   ("Note", "Warning", "Important" or their i18n equivalents).    
 
+   This could be done with a single clause $('p.admonition-title')...., 
+   affecting all types of admonitions. I play it safe here and explicitly 
+   work on the three openstackdocstheme admonitions.                           
+   
+   The first parameter of the text() callback is not needed here (it's 
+   the index of the HTML element that we are modifying)                 */
+
+$('div.important > p.admonition-title').text(function(ignored_para,original) {
+    return " "+original
+});
+$('div.note > p.admonition-title').text(function(ignored_para,original) {
+    return " "+original
+});
+$('div.warning > p.admonition-title').text(function(ignored_para,original) {
+    return " "+original
+});
 
